Module types

Module types 

Types used as operation parameters and responses.

Modules

builder
Types for composing complex structures.
error
Error types.

Structs

AtomicAmount
Non-negative integer amount in USDC atomic units.
Attachment
Attachment
Attachments
Attachments
ChainNetwork
ChainNetwork
ErrorEnvelope
ErrorEnvelope
ErrorEnvelopeError
ErrorEnvelopeError
GetModel
GetModel
HealthResponse
HealthResponse
LegacyError
LegacyError
Message
Message
ModalityCatalogEntry
ModalityCatalogEntry
ModalityListResponse
ModalityListResponse
Model
Model
ModelListResponse
ModelListResponse
ModelOperationCapability
ModelOperationCapability
ModelOperationCapabilityOperation
ModelOperationCapabilityOperation
ModelParamsResponse
ModelParamsResponse
ModelSearchRequest
ModelSearchRequest
ModelSearchRequestOperation
ModelSearchRequestOperation
ModelSearchResponse
ModelSearchResponse
OperationCatalogEntry
OperationCatalogEntry
OperationCatalogEntryOperation
OperationCatalogEntryOperation
OperationListResponse
OperationListResponse
OperationModel
OperationModel
OperationModelsListOperation
OperationModelsListOperation
OperationModelsResponse
OperationModelsResponse
ParamsGetModel
ParamsGetModel
PaymentRequired
PaymentRequired
PaymentRequiredResource
PaymentRequiredResource
PaymentRequiredX402Version
PaymentRequiredX402Version
PaymentRequirements
PaymentRequirements
PricingUnit
PricingUnit
PricingUnitUnitKey
PricingUnitUnitKey
ReasoningOptions
ReasoningOptions
ReceiptBody
ReceiptBody
ReceiptLineItem
ReceiptLineItem
ResponseEventStream
SSE frames for response creation, text deltas, reasoning deltas, tool calls, image partials, typed output items for text/image/audio/video/embedding, video status, completion, receipt, and compose.error.
ResponseFormat
ResponseFormat
ResponseObject
ResponseObject
ResponsesCancelResponseId
ResponsesCancelResponseId
ResponsesCreateRequest
ResponsesCreateRequest
ResponsesCreateXIdempotencyKey
ResponsesCreateXIdempotencyKey
ResponsesGetResponseId
ResponsesGetResponseId
ResponsesInputItemsListResponse
ResponsesInputItemsListResponse
ResponsesInputItemsListResponseId
ResponsesInputItemsListResponseId
StreamOptions
StreamOptions
WalletAddress
WalletAddress

Enums

AttachmentDetail
AttachmentDetail
AttachmentInput
AttachmentInput
AttachmentType
Advisory attachment kind. The SDK/server do not reject unsupported model combinations.
CanonicalModality
CanonicalModality
GetResponse
GetResponse
MessageContent
MessageContent
MessageRole
MessageRole
ModalityGetResponse
ModalityGetResponse
ModalityListResponseObject
ModalityListResponseObject
ModelCreatedAt
ModelCreatedAt
ModelListResponseObject
ModelListResponseObject
ModelProvider
ModelProvider
ModelSearchResponseObject
ModelSearchResponseObject
ModelType
ModelType
OperationListResponseObject
OperationListResponseObject
OperationModelCreatedAt
OperationModelCreatedAt
OperationModelType
OperationModelType
OperationModelsListResponse
OperationModelsListResponse
OperationModelsResponseObject
OperationModelsResponseObject
OperationsListResponse
OperationsListResponse
PaymentRequirementsScheme
PaymentRequirementsScheme
ResponseFormatType
ResponseFormatType
ResponseObjectObject
ResponseObjectObject
ResponseObjectStatus
ResponseObjectStatus
ResponsesCreateRequestModalitiesItem
ResponsesCreateRequestModalitiesItem
ResponsesCreateResponse
ResponsesCreateResponse
ResponsesGetResponse
ResponsesGetResponse
ResponsesInputItemsListResponseObject
ResponsesInputItemsListResponseObject